@@ -46,10 +46,7 @@
 ;;; Options
 
 (defcustom forge-limit-topic-choices t
-  "Whether to initially limit completion candidates to active topics.
-
-For Helm users setting this option has no effect.  Instead they have
-to set the value of the variable `forge-limit-topic-choices-for-helm'."
+  "Whether to initially limit completion candidates to active topics."
   :package-version '(forge . "0.4.0")
   :group 'forge
   :type 'boolean)
@@ -720,14 +717,10 @@ can be selected from the start."
   (forge--read-topic prompt
                      #'forge-current-topic
                      (forge--topics-spec :type 'topic :active t)
-                     (forge--topics-spec :type 'topic :active nil :state nil)))
-
-(defvar forge-limit-topic-choices-for-helm t
-  "Like `forge-limit-topic-choices' (which see) but for Helm users.")
+                     (forge--topics-spec :type 'topic :active nil
+                                         :state nil :limit nil)))
 
 (defun forge--read-topic (prompt current active all)
-  (when (bound-and-true-p helm-mode)
-    (setq forge-limit-topic-choices forge-limit-topic-choices-for-helm))
   (let* ((current (funcall current))
          (repo    (forge-get-repository (or current :tracked)))
          (default (and current (forge--format-topic-line current)))
@@ -756,13 +749,19 @@ can be selected from the start."
                  (completion-table-dynamic
                   (let (all-choices)
                     (lambda (_string)
-                      (cond
-                        (all-choices)
-                        (forge-limit-topic-choices choices)
-                        (t
-                         (setq alist (forge--topic-collection
-                                      (forge--list-topics all repo)))
-                         (setq all-choices (mapcar #'car alist)))))))
+                      ;; For other frameworks, the minibuffer is current
+                      ;; when this function is called, but for Helm we
+                      ;; have to make it so.  Starting with Helm commit
+                      ;; 5e7c8498, this isn't necessary anymore.  See
+                      ;; https://github.com/emacs-helm/helm/issues/2744.
+                      (with-selected-window (minibuffer-window)
+                        (cond
+                          (all-choices)
+                          (forge-limit-topic-choices choices)
+                          (t
+                           (setq alist (forge--topic-collection
+                                        (forge--list-topics all repo)))
+                           (setq all-choices (mapcar #'car alist))))))))
                  nil t nil nil default))
             (magit-completing-read prompt choices nil t nil nil default))))
     (cdr (assoc choice alist))))
@@ -780,20 +779,17 @@ can be selected from the start."
   (interactive)
   (when (and (minibufferp)
              forge-limit-topic-choices)
+    (setq-local forge-limit-topic-choices nil)
     (cond
       ((and (bound-and-true-p vertico-mode)
             (boundp 'vertico--input)
             (fboundp 'vertico--exhibit))
-       (setq-local forge-limit-topic-choices nil)
        (setq vertico--input t)
        (vertico--exhibit))
       ((and (bound-and-true-p helm-mode)
             (fboundp 'helm-force-update))
-       (setq forge-limit-topic-choices nil)
        (helm-force-update))
-      (t
-       (setq-local forge-limit-topic-choices nil)
-       (minibuffer-completion-help (minibuffer--completion-prompt-end)
+      ((minibuffer-completion-help (minibuffer--completion-prompt-end)
                                    (point-max))))
     (forge-read-topic--remove-prompt-hint)))
 
